@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::Author::ALEXBIO;
 BEGIN {
-  $Dist::Zilla::PluginBundle::Author::ALEXBIO::VERSION = '0.04';
+  $Dist::Zilla::PluginBundle::Author::ALEXBIO::VERSION = '0.05';
 }
 
 use Moose;
@@ -10,6 +10,8 @@ use Dist::Zilla::Plugin::Git;
 use Dist::Zilla::Plugin::GitHub;
 use Dist::Zilla::Plugin::ChangelogFromGit;
 
+use Dist::Zilla::Plugin::MakeMaker::Awesome;
+
 use Dist::Zilla::Plugin::Clean;
 use Dist::Zilla::Plugin::InstallRelease;
 
@@ -18,13 +20,33 @@ use strict;
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
+has 'makemaker' => (
+	is      => 'ro',
+	isa     => 'Bool',
+	lazy    => 1,
+	default => sub {
+			defined $_[0] -> payload -> {makemaker} ?
+				$_[0] -> payload -> {makemaker} : 1
+		}
+);
+
+has 'fake_release' => (
+	is      => 'ro',
+	isa     => 'Bool',
+	lazy    => 1,
+	default => sub {
+			defined $_[0] -> payload -> {fake_release} ?
+				$_[0] -> payload -> {fake_release} : 0
+		}
+);
+
 =head1 NAME
 
 Dist::Zilla::PluginBundle::Author::ALEXBIO - ALEXBIO's default Dist::Zilla config
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -68,11 +90,29 @@ equivalent to the following:
 sub configure {
 	my $self = shift;
 
-	# basic bundle
-	$self -> add_bundle(
-		'Basic'
+	# @Basic plugins but MakeMaker and UploadToCPAN
+	$self -> add_plugins(
+		'GatherDir',
+		'PruneCruft',
+		'ManifestSkip',
+		'MetaYAML',
+		'License',
+		'Readme',
+		'ExtraTests',
+		'ExecDir',
+		'ShareDir',
+		'Manifest',
+		'TestRelease',
+		'ConfirmRelease',
 	);
 
+	# use MakeMaker if requested
+	if ($self -> makemaker) {
+		$self -> add_plugins(
+			'MakeMaker'
+		);
+	}
+
 	# github bundle
 	$self -> add_bundle(
 		'GitHub'
@@ -87,20 +127,24 @@ sub configure {
 		'PkgVersion'
 	);
 
-	# git plugins
 	$self -> add_plugins(
 		['ChangelogFromGit' => {
 			tag_regexp => '^v',
 			file_name  => 'Changes'
 		}],
-
-		['Git::Tag' => {
-			tag_message => '%N %v'
-		}],
-
-		'Git::Push'
 	);
 
+	# release plugins
+	if ($self -> fake_release) {
+		$self -> add_plugins( 'FakeRelease' );
+	} else {
+		$self -> add_plugins(
+			['Git::Tag' => { tag_message => '%N %v' }],
+			'Git::Push',
+			'UploadToCPAN'
+		);
+	}
+
 	# after release
 	$self -> add_plugins(
 		['InstallRelease' => {
@@ -111,6 +155,20 @@ sub configure {
 	);
 }
 
+=head1 ATTRIBUTES
+
+=over
+
+=item C<makemaker>
+
+If set to '1' (default), the C<MakeMaker> plugin is used.
+
+=item C<fake_relase>
+
+If set to '1', the release will be faked using the C<FakeRelease> plugin.
+
+=back
+
 =head1 AUTHOR
 
 Alessandro Ghedini <alexbio@cpan.org>
